summaryrefslogtreecommitdiff
path: root/src/engine
diff options
context:
space:
mode:
authorSteven Knight <knight@baldmt.com>2005-08-13 00:56:13 +0000
committerSteven Knight <knight@baldmt.com>2005-08-13 00:56:13 +0000
commit90376f36df71401df8e7cf71fead9b7869153159 (patch)
treeb2ee287041efacbaaa6f4cdd226f62590bff0e09 /src/engine
parent055a212a12d75036cdfbaf2b954e39908a2fbac1 (diff)
downloadscons-90376f36df71401df8e7cf71fead9b7869153159.tar.gz
Add %SYSTEMDRIVE% to the list of Windows variables preserved. (Chris Prince)
Diffstat (limited to 'src/engine')
-rw-r--r--src/engine/SCons/Platform/win32.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/engine/SCons/Platform/win32.py b/src/engine/SCons/Platform/win32.py
index 6faf606d..61880987 100644
--- a/src/engine/SCons/Platform/win32.py
+++ b/src/engine/SCons/Platform/win32.py
@@ -232,9 +232,11 @@ def generate(env):
# environment's ENV. This is a potential slippery slope, because we
# *don't* want to make builds dependent on the user's environment by
# default. We're doing this for SYSTEMROOT, though, because it's
- # needed for anything that uses sockets, and seldom changes. Weigh
- # the impact carefully before adding other variables to this list.
- import_env = [ 'SYSTEMROOT', 'TEMP', 'TMP' ]
+ # needed for anything that uses sockets, and seldom changes, and
+ # for SYSTEMDRIVE because it's related.
+ #
+ # Weigh the impact carefully before adding other variables to this list.
+ import_env = [ 'SYSTEMDRIVE', 'SYSTEMROOT', 'TEMP', 'TMP' ]
for var in import_env:
v = os.environ.get(var)
if v: